@@ -6,7 +6,6 @@ package repo
 import (
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"net/http"
 	"net/http/httptest"
@@ -15,7 +14,7 @@ import (
 	"testing"
 	"time"
 
-	"github.com/stolostron/multiclusterhub-repo/pkg/config"
+	"github.com/open-cluster-management/multiclusterhub-repo/pkg/config"
 	"helm.sh/helm/v3/pkg/repo"
 	"sigs.k8s.io/yaml"
 )
@@ -156,7 +155,7 @@ func Test_createIndex(t *testing.T) {
 
 func TestReindex(t *testing.T) {
 	// Serve charts in tempDir
-	tmpDir, err := ioutil.TempDir("testdata", "charts_tmp_")
+	tmpDir, err := os.MkdirTemp("testdata", "charts_tmp_")
 	if err != nil {
 		t.Fatalf("Could not create chart dir")
 	}
@@ -223,7 +222,7 @@ func TestReindex(t *testing.T) {
 
 // helper for getting an index from an http response
 func getIndex(res io.Reader) (*repo.IndexFile, error) {
-	b, err := ioutil.ReadAll(res)
+	b, err := io.ReadAll(res)
 	i := &repo.IndexFile{}
 	if err != nil {
 		return i, err
